@@ -14,6 +14,8 @@ module PuppetMetadata
       {
         puppet_major_versions: puppet_major_versions,
         puppet_unit_test_matrix: puppet_unit_test_matrix,
+        puppet_beaker_test_matrix: puppet_beaker_test_matrix,
+        # Deprecated
         github_action_test_matrix: github_action_test_matrix,
       }
     end
@@ -61,8 +63,10 @@ module PuppetMetadata
         else
           releases&.each do |release|
             majors.each do |puppet_version|
-              if AIO.has_aio_build?(os, release, puppet_version[:value]) # rubocop:disable Style/IfUnlessModifier
+              if AIO.has_aio_build?(os, release, puppet_version[:value])
                 yield [os, release, puppet_version]
+              elsif PuppetMetadata::OperatingSystem.os_release_puppet_version(os, release) == puppet_version[:value]
+                yield [os, release, distro_puppet_version.merge(value: puppet_version[:value])]
               end
             end
           end
@@ -70,17 +74,51 @@ module PuppetMetadata
       end
     end
 
+    def puppet_beaker_test_matrix
+      matrix_include = []
+
+      beaker_os_releases do |os, release, puppet_version|
+        next if puppet_version_below_minimum?(puppet_version[:value])
+
+        setfile = os_release_to_beaker_setfile(os, release, puppet_version[:collection])
+        next unless setfile
+
+        name = "#{puppet_version[:name]} - #{setfile[1]}"
+        env = {
+          'BEAKER_PUPPET_COLLECTION' => puppet_version[:collection],
+          'BEAKER_SETFILE' => setfile[0],
+        }
+
+        if options[:beaker_facter]
+          fact, label, values = options[:beaker_facter]
+          values.each do |value|
+            matrix_include << {
+              name: "#{name} - #{label || fact} #{value}",
+              env: env.merge("BEAKER_FACTER_#{fact}" => value),
+            }
+          end
+        else
+          matrix_include << {
+            name: name,
+            env: env,
+          }
+        end
+      end
+
+      matrix_include
+    end
+
     def github_action_test_matrix
       matrix_include = []
 
       beaker_os_releases do |os, release, puppet_version|
-        setfile = PuppetMetadata::Beaker.os_release_to_setfile(
-          os, release, use_fqdn: options[:beaker_use_fqdn], pidfile_workaround: options[:beaker_pidfile_workaround], domain: options[:domain], puppet_version: puppet_version[:collection]
-        )
-        next unless setfile
         next if puppet_version_below_minimum?(puppet_version[:value])
 
+        setfile = os_release_to_beaker_setfile(os, release, puppet_version[:collection])
+        next unless setfile
+
         matrix_include << {
+          name: "#{puppet_version[:name]} - #{setfile[1]}",
           setfile: {
             name: setfile[1],
             value: setfile[0],
@@ -97,5 +135,16 @@ module PuppetMetadata
 
       Gem::Version.new(version) < Gem::Version.new(options[:minimum_major_puppet_version])
     end
+
+    def os_release_to_beaker_setfile(os, release, puppet_collection)
+      PuppetMetadata::Beaker.os_release_to_setfile(
+        os,
+        release,
+        use_fqdn: options[:beaker_use_fqdn],
+        pidfile_workaround: options[:beaker_pidfile_workaround],
+        domain: options[:domain],
+        puppet_version: puppet_collection,
+      )
+    end
   end
 end
